@@ -26,9 +26,3 @@ def notify(event, jid, account, parameters, advanced_notif_num = None):
 
 def get_advanced_notification(event, account, contact):
     return None
-
-def get_show_in_roster(event, account, jid, session=None):
-    return True
-
-def get_show_in_systray(event, account, jid, type_=None):
-    return True
